/*
Copyright (c) 2000-2006 The Legion Of The Bouncy Castle (http://www.bouncycastle.org)
Copyright (c) 2006, CARDON DE LICHTBUER Rodolphe
All rights reserved.
 
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
 
1. Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.
 
2. Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.
 
3. The name of the author or contributors may not be used to endorse or promote
products derived from this software without specific prior written permission.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
 
 */

package be.cardon.asn1.x509;

import org.bouncycastle.asn1.ASN1Encodable;
import org.bouncycastle.asn1.ASN1EncodableVector;
import org.bouncycastle.asn1.ASN1Sequence;
import org.bouncycastle.asn1.ASN1TaggedObject;
import org.bouncycastle.asn1.DERObject;
import org.bouncycastle.asn1.DERSequence;
import org.bouncycastle.asn1.DERTaggedObject;

import org.bouncycastle.asn1.x509.GeneralSubtree;
import java.util.Vector;
/**
 *Implements the {@code GeneralSubtrees} {@literal ASN.1} definition from RFC 3280.
 * @author crackapat
 */
public class GeneralSubtrees extends ASN1Encodable{
    
    private Vector<GeneralSubtree> subtrees;
    
    
    
    /** Creates a new instance of GeneralSubtrees */
    public GeneralSubtrees(Vector<GeneralSubtree> subtrees) {
        this.subtrees = subtrees;
    }

    public Vector<GeneralSubtree> getSubtrees() {
        return subtrees;
    }

    public GeneralSubtrees(ASN1Sequence seq){
        subtrees = new Vector<GeneralSubtree>();
        for(int i=0;i<seq.size();i++){
            subtrees.add(GeneralSubtree.getInstance(seq.getObjectAt(i)));
        }
    }
    
    public static GeneralSubtrees getInstance(Object obj){
        if(obj instanceof GeneralSubtrees){
            return (GeneralSubtrees)obj;
        }
        if(obj instanceof ASN1Sequence){
            return new GeneralSubtrees((ASN1Sequence)obj);
        }
        throw new IllegalArgumentException("invalid ASN1Sequence");
    }
    
    public DERObject toASN1Object(){
        ASN1EncodableVector vec = new ASN1EncodableVector();
        for(int i=0;i<subtrees.size();i++){
           vec.add(subtrees.get(i).getDERObject());
        }
        return new DERSequence(vec);
    }

}
