/*
Copyright (c) 2000-2006 The Legion Of The Bouncy Castle (http://www.bouncycastle.org) 
Copyright (c) 2006, CARDON DE LICHTBUER Rodolphe
All rights reserved.
 
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
 
1. Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.
 
2. Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.
 
3. The name of the author or contributors may not be used to endorse or promote
products derived from this software without specific prior written permission.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
 
 */

package be.cardon.asn1.x509.extensions;

import be.cardon.asn1.x509.*;
import org.bouncycastle.asn1.ASN1Encodable;
import org.bouncycastle.asn1.ASN1EncodableVector;
import org.bouncycastle.asn1.ASN1Sequence;
import org.bouncycastle.asn1.ASN1TaggedObject;
import org.bouncycastle.asn1.ASN1OctetString;
import org.bouncycastle.asn1.DERObject;
import org.bouncycastle.asn1.DERObjectIdentifier;
import org.bouncycastle.asn1.DERSequence;
import org.bouncycastle.asn1.DERInteger;
import java.math.BigInteger;
/**Extension {@code InhibitAnyPolicy}.
  
   <p>Documentation from <b>RFC 3280</b>:</p>
   <p>The inhibit any-policy extension can be used in certificates issued
   to CAs.  The inhibit any-policy indicates that the special anyPolicy
   OID, with the value { 2 5 29 32 0 }, is not considered an explicit
   match for other certificate policies.  The value indicates the number
   of additional certificates that may appear in the path before
   anyPolicy is no longer permitted.  For example, a value of one
   indicates that anyPolicy may be processed in certificates issued by
   the subject of this certificate, but not in additional certificates
   in the path.</p>

   <p>This extension MUST be critical.</p>
  
   <p>ASN.1 definitions:</p>
   <pre>
   id-ce-inhibitAnyPolicy OBJECT IDENTIFIER ::=  { id-ce 54 }

   InhibitAnyPolicy ::= SkipCerts

   SkipCerts ::= INTEGER (0..MAX)
   </pre>
 * @author crackapat
 */
public class InhibitAnyPolicy extends DERInteger{
        
    /**Creates an new instance with the given {@code skipCerts}.*/
    public InhibitAnyPolicy(
        int         skipCerts)
    {
        super(skipCerts);
    }
    
    /**Creates an new instance with the given {@code skipCerts}.*/    
    public InhibitAnyPolicy(
        DERInteger  skipCerts)
    {
        super(skipCerts.getValue());
    }

    /**Creates an new instance with the given {@code skipCerts}.*/    
    public InhibitAnyPolicy(
        BigInteger   skipCerts)
    {
        super(skipCerts);
    }

    /**Creates an new instance with the given {@code skipCerts}.*/
    public InhibitAnyPolicy(
        byte[]   skipCerts)
    {
        super(skipCerts);
    }
    
    /**Returns the {@code skipCerts} value.
     * <p>This function is an alias for {@code DERInteger.getValue().intValue()}</p>.
     */
    public int getSkipCerts(){
        return super.getValue().intValue();
    }
    
    /**Returns an instance from a {@code DERInteger}, 
     *a {@code ASN1OctetString}, or a {@code ASN1TaggedObject} object.*/   
    public static InhibitAnyPolicy getInstance(
        Object  obj)
    {
        if (obj == null || obj instanceof DERInteger)
        {
            return new InhibitAnyPolicy((DERInteger)obj);
        }

        if (obj instanceof ASN1OctetString)
        {
            return new InhibitAnyPolicy(((ASN1OctetString)obj).getOctets());
        }

        if (obj instanceof ASN1TaggedObject)
        {
            return getInstance(((ASN1TaggedObject)obj).getObject());
        }

        throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
    }
}