/*
Copyright (c) 2000-2006 The Legion Of The Bouncy Castle (http://www.bouncycastle.org) 
Copyright (c) 2006, CARDON DE LICHTBUER Rodolphe
All rights reserved.
 
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
 
1. Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.
 
2. Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.
 
3. The name of the author or contributors may not be used to endorse or promote
products derived from this software without specific prior written permission.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
 
 */

package be.cardon.asn1.x509.extensions;

import be.cardon.asn1.x509.*;

import org.bouncycastle.asn1.ASN1Encodable;
import org.bouncycastle.asn1.ASN1EncodableVector;
import org.bouncycastle.asn1.ASN1Sequence;
import org.bouncycastle.asn1.ASN1TaggedObject;
import org.bouncycastle.asn1.DERObject;
import org.bouncycastle.asn1.DERObjectIdentifier;
import org.bouncycastle.asn1.DERSequence;

import java.util.Vector;

/**Extension {@code IssuerAltName}.
  
   <p>Documentation from <b>RFC 3280</b>:</p>
 
   <p>As with 4.2.1.7 (see {@link SubjectAltName SubjectAltName}), 
   this extension is used to associate Internet style
   identities with the certificate issuer.  Issuer alternative names
   MUST be encoded as in 4.2.1.7.</p>

   <p>Where present, this extension SHOULD NOT be marked critical.</p>

   <p>ASN.1 definitions:</p>
   <pre>
   id-ce-issuerAltName OBJECT IDENTIFIER ::=  { id-ce 18 }

   IssuerAltName ::= GeneralNames
   </pre>
 *@see SubjectAltName
 *@see GeneralNames
 *@author crackapat
 */
public class IssuerAltName
    extends GeneralNames{
    
    /**Returns a new instance from an {@code ASN1Sequence}, or a {@code GeneralNames},
      or a {@code IssuerAltName} object.*/
    public static IssuerAltName getInstance(
        Object  obj)
    {
        if (obj == null || obj instanceof IssuerAltName)
        {
            return (IssuerAltName)obj;
        }
        
        if(obj instanceof GeneralNames)
        {    
            return new IssuerAltName((GeneralNames)obj);
        }
        if (obj instanceof ASN1Sequence)
        {
            return new IssuerAltName((ASN1Sequence)obj);
        }

        throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
    }
    
    /** Creates an new object from an existing {@literal ASN.1} tagged object.*/
    public static IssuerAltName getInstance(
        ASN1TaggedObject obj,
        boolean          explicit)
    {
        return getInstance(ASN1Sequence.getInstance(obj, explicit));
    }

    /**Creates a new instance containing one {@code GeneralName}.
     * @param name the name to be contained.
     */
    public IssuerAltName(
        GeneralName  name)
    {
        super(name);
    }
    /**Creates a new instance containing the given {@code GeneralNames}.
     */    
    public IssuerAltName(
        GeneralNames  names)
    {
        super(names.getGeneralNameVector());
    }
    
     /**Creates a new instance from a {@code ASN1Sequence}.*/
    public IssuerAltName(
        ASN1Sequence  seq)
    {
        super(seq);
    }
    /**Returns the vector of {@code GeneralName}. 
     * <p>This vector may be empty but is never {@code null}.</p>
     * <p>This function is an alias for {@link GeneralNames#getGeneralNameVector}.</p>
     */  
    public Vector<GeneralName> getGeneralNames(){
        return this.getGeneralNameVector();
    }
}

